==> knative-model-6.7.1-sources.jar: io/fabric8/knative/sources/v1/ApiServerSourceListBuilder.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ApiServerSourceListBuilder extends ApiServerSourceListFluentImpl<ApiServerSourceListBuilder> implements VisitableBuilder<ApiServerSourceList,ApiServerSourceListBuilder>{
  public ApiServerSourceListBuilder() {
    this(false);
  }
  public ApiServerSourceListBuilder(Boolean validationEnabled) {
    this(new ApiServerSourceList(), validationEnabled);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ApiServerSourceList(), validationEnabled);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,ApiServerSourceList instance) {
    this(fluent, instance, false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,ApiServerSourceList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ApiServerSourceListBuilder(ApiServerSourceList instance) {
    this(instance,false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ApiServerSourceListFluent<?> fluent;
  Boolean validationEnabled;
  public ApiServerSourceList build() {
    ApiServerSourceList buildable = new ApiServerSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/sources/v1/ApiServerSourceListBuilder.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ApiServerSourceListBuilder extends ApiServerSourceListFluent<ApiServerSourceListBuilder> implements VisitableBuilder<ApiServerSourceList,ApiServerSourceListBuilder>{
  public ApiServerSourceListBuilder() {
    this(false);
  }
  public ApiServerSourceListBuilder(Boolean validationEnabled) {
    this(new ApiServerSourceList(), validationEnabled);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ApiServerSourceList(), validationEnabled);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,ApiServerSourceList instance) {
    this(fluent, instance, false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceListFluent<?> fluent,ApiServerSourceList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ApiServerSourceList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ApiServerSourceListBuilder(ApiServerSourceList instance) {
    this(instance,false);
  }
  public ApiServerSourceListBuilder(ApiServerSourceList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ApiServerSourceList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ApiServerSourceListFluent<?> fluent;
  Boolean validationEnabled;
  public ApiServerSourceList build() {
    ApiServerSourceList buildable = new ApiServerSourceList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
